@@ -83,6 +83,10 @@ void        gs_window_set_logout_command (GSWindow   *window,
                                           const char *command);
 void        gs_window_set_status_message   (GSWindow   *window,
                                             const char *status_message);
+void        gs_window_show_message         (GSWindow   *window,
+                                            const char *summary,
+                                            const char *body,
+                                            const char *icon);
 
 void        gs_window_request_unlock     (GSWindow  *window);
 void        gs_window_cancel_unlock_request (GSWindow  *window);
